options nosource nonotes nomprint;
data aa(keep=pid date hour bc_mean spring traffic);
  set s_data.Ae51_bc_allsiteout_fall_hourly s_data.Ae51_bc_allsiteout_spr_hourly(in=a);
  if (a) then spring=1;
  else spring=0;
  if hour in (5,6,7,8,9) then traffic="high";
  else if  hour in (11,12,13,14,15,16,17) then traffic="low";
  else traffic="med";

    if index(samplesite,"100 meters") then pid=1;
  else if  index(samplesite,"Maybury") then pid=2;
  else if  index(samplesite,"Ludington") then pid=3;
  else pid=substr(samplesite,2);
run;


proc sort data=aa;
  by spring traffic;
run;

proc means noprint data=aa;
  var bc_mean;
  output out=a_avg(drop=_:) n=n mean=mean std=std p5=p5 p25=p25 p50=p50 p75=p75 p95=p95;
  by spring traffic;
run;

proc export data=a_avg outfile="./tab/b_ana02.xls" replace;
  sheet="a_avg";
run;

proc sort data=aa;
  by pid spring  traffic;
run;

proc means data=aa noprint;
  var bc_mean;
  output out=aa1 mean=;
  by  pid spring traffic;
run;

proc means data=aa noprint;
  var bc_mean;
  output out=aa1a mean=;
  by  pid spring ;
run;
 
proc means data=aa noprint;
  var bc_mean;
  output out=aa1b mean=;
  by  pid ;
run;


data aa2;
 merge aa1 loc.a_mj_idx;
 by pid;
run;

data aa2a;
 merge aa1a loc.a_mj_idx;
 by pid;
run;

data aa2b;
 merge aa1b loc.a_mj_idx;
 by pid;
run;

proc sort data=aa2;
  by spring traffic;
run;

proc sort data=aa2a;
  by spring ;
run;


ods output  PearsonCorr=z_corr1;
proc corr data=aa2 ;
  var pppNO: mj:;
  with bc_mean;
  by spring traffic;
run;
ods output close;



ods output  PearsonCorr=z_corr2;
proc corr data=aa2a ;
  var pppNO: mj:;
  with bc_mean;
  by spring ;
run;
quit;
ods output close;

ods output  PearsonCorr=z_corr3;
proc corr data=aa2b ;
  var pppNO: mj:;
  with bc_mean;
run;
quit;
ods output close;

data z_corr3a(keep=mj_metric r_:);
 length mj_metric $12 r_50	r_100	r_150	r_200	r_250	r_300 r_mean $10;
 set z_corr3;
 array oo{6} r_50	r_100	r_150	r_200	r_250	r_300 ;
 array mj{6} pppNO50	pppNO100	pppNO150	pppNO200	pppNO250	pppNO300;
 array aa{6} mjAADT50	mjAADT100	mjAADT150	mjAADT200	mjAADT250	mjAADT300;
 array cc{6} mjCADT50	mjCADT100	mjCADT150	mjCADT200	mjCADT250	mjCADT300;
 array pmj{6} PpppNO50	PpppNO100	PpppNO150	PpppNO200	PpppNO250	PpppNO300;
 array paa{6} PmjAADT50	PmjAADT100	PmjAADT150	PmjAADT200	PmjAADT250	PmjAADT300;
 array pcc{6} PmjCADT50	PmjCADT100	PmjCADT150	PmjCADT200	PmjCADT250	PmjCADT300;
 do i=1 to 6;
   mj_metric=" MJ cover(%)";
   if Pmj{i} > 0.05 then      tmp="  ";
   else if Pmj{i} > 0.01 then tmp="* ";
   else                       tmp="**";
   oo{i}=put(mj{i},5.2)||left(tmp);   
 end;
   r_mean= put(mean(of pppNO50	pppNO100	pppNO150	pppNO200	pppNO250	pppNO300),5.2) ;

 output;
 do i=1 to 6;
   mj_metric="AADT density";
   if Paa{i} > 0.05 then      tmp="  ";
   else if Paa{i} > 0.01 then tmp="* ";
   else                       tmp="**";
   oo{i}=put(aa{i},5.2)||left(tmp);   
 end;
   r_mean= put(mean(of mjAADT50	mjAADT100	mjAADT150	mjAADT200	mjAADT250	mjAADT300),5.2)	;

 output;
 do i=1 to 6;
   mj_metric="CADT density";
   if Pcc{i} > 0.05 then      tmp="  ";
   else if Pcc{i} > 0.01 then tmp="* ";
   else                       tmp="**";
   oo{i}=put(cc{i},5.2)||left(tmp);   
 end;
   r_mean= put(mean(of mjCADT50	mjCADT100	mjCADT150	mjCADT200	mjCADT250	mjCADT300),5.2)	;

 output;
run;

data z_corr2a(keep=season mj_metric r_:);
 length mj_metric season $12 r_50	r_100	r_150	r_200	r_250	r_300 r_mean $10;
 set z_corr2;
 array oo{6} r_50	r_100	r_150	r_200	r_250	r_300 ;
 array mj{6} pppNO50	pppNO100	pppNO150	pppNO200	pppNO250	pppNO300;
 array aa{6} mjAADT50	mjAADT100	mjAADT150	mjAADT200	mjAADT250	mjAADT300;
 array cc{6} mjCADT50	mjCADT100	mjCADT150	mjCADT200	mjCADT250	mjCADT300;
 array pmj{6} PpppNO50	PpppNO100	PpppNO150	PpppNO200	PpppNO250	PpppNO300;
 array paa{6} PmjAADT50	PmjAADT100	PmjAADT150	PmjAADT200	PmjAADT250	PmjAADT300;
 array pcc{6} PmjCADT50	PmjCADT100	PmjCADT150	PmjCADT200	PmjCADT250	PmjCADT300;
 if spring=1 then season="Spring";
 else season="Fall";
 do i=1 to 6;
   mj_metric=" MJ cover(%)";
   if Pmj{i} > 0.05 then      tmp="  ";
   else if Pmj{i} > 0.01 then tmp="* ";
   else                       tmp="**";
   oo{i}=put(mj{i},5.2)||left(tmp);   
 end;
  r_mean= put(mean(of pppNO50	pppNO100	pppNO150	pppNO200	pppNO250	pppNO300),5.2) ;
 output;
 do i=1 to 6;
   mj_metric="AADT density";
   if Paa{i} > 0.05 then      tmp="  ";
   else if Paa{i} > 0.01 then tmp="* ";
   else                       tmp="**";
   oo{i}=put(aa{i},5.2)||left(tmp);   
 end;
  r_mean= put(mean(of mjAADT50	mjAADT100	mjAADT150	mjAADT200	mjAADT250	mjAADT300),5.2)	;
 output;
 do i=1 to 6;
   mj_metric="CADT density";
   if Pcc{i} > 0.05 then      tmp="  ";
   else if Pcc{i} > 0.01 then tmp="* ";
   else                       tmp="**";
   oo{i}=put(cc{i},5.2)||left(tmp);   
 end;
  r_mean= put(mean(of mjCADT50	mjCADT100	mjCADT150	mjCADT200	mjCADT250	mjCADT300),5.2)	;
 output;
run;

data z_corr1a(keep=season tr mj_metric r_:);
 length mj_metric season tr  $12 r_50	r_100	r_150	r_200	r_250	r_300 r_mean $10;
 set z_corr1;
 array oo{6} r_50	r_100	r_150	r_200	r_250	r_300 ;
 array mj{6} pppNO50	pppNO100	pppNO150	pppNO200	pppNO250	pppNO300;
 array aa{6} mjAADT50	mjAADT100	mjAADT150	mjAADT200	mjAADT250	mjAADT300;
 array cc{6} mjCADT50	mjCADT100	mjCADT150	mjCADT200	mjCADT250	mjCADT300;
 array pmj{6} PpppNO50	PpppNO100	PpppNO150	PpppNO200	PpppNO250	PpppNO300;
 array paa{6} PmjAADT50	PmjAADT100	PmjAADT150	PmjAADT200	PmjAADT250	PmjAADT300;
 array pcc{6} PmjCADT50	PmjCADT100	PmjCADT150	PmjCADT200	PmjCADT250	PmjCADT300;
 tr=traffic;
 if spring=1 then season="Spring";
 else season="Fall";
 if tr="high" then tr="z high";
 do i=1 to 6;
   mj_metric=" MJ cover(%)";
   if Pmj{i} > 0.05 then      tmp="  ";
   else if Pmj{i} > 0.01 then tmp="* ";
   else                       tmp="**";
   oo{i}=put(mj{i},5.2)||left(tmp);   
 end;
  r_mean= put(mean(of pppNO50	pppNO100	pppNO150	pppNO200	pppNO250	pppNO300),5.2) ;

 output;
 do i=1 to 6;
   mj_metric="AADT density";
   if Paa{i} > 0.05 then      tmp="  ";
   else if Paa{i} > 0.01 then tmp="* ";
   else                       tmp="**";
   oo{i}=put(aa{i},5.2)||left(tmp);   
 end;
   r_mean= put(mean(of mjAADT50	mjAADT100	mjAADT150	mjAADT200	mjAADT250	mjAADT300),5.2)	;

 output;
 do i=1 to 6;
   mj_metric="CADT density";
   if Pcc{i} > 0.05 then      tmp="  ";
   else if Pcc{i} > 0.01 then tmp="* ";
   else                       tmp="**";
   oo{i}=put(cc{i},5.2)||left(tmp);   
 end;
  r_mean= put(mean(of mjCADT50	mjCADT100	mjCADT150	mjCADT200	mjCADT250	mjCADT300),5.2)	;

 output;
run;

proc sort data=z_corr1a;
 by mj_metric season tr;
run;
proc sort data=z_corr2a;
 by mj_metric season ;
run;
proc sort data=z_corr3a;
 by mj_metric;
run;

proc export data=z_corr3a outfile="./tab/b_ana02.xls" replace;
  sheet="corr";
run;

proc export data=z_corr2a outfile="./tab/b_ana02.xls" replace;
  sheet="corr_spring";
run;

proc export data=z_corr1a outfile="./tab/b_ana02.xls" replace;
  sheet="corr_traffic";
run;

